<?php

namespace App\Http\Controllers;

use App\Http\Controllers\CompanyRoleController;
use App\Models\User;
use App\Models\Site;
use App\Models\SiteUser;
use Illuminate\Http\Request;
use App\Http\Requests\Admin\SiteUsersRequest;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Auth;
use Config;
use DB;

class SiteUsersController extends CompanyRoleController
{
    protected static $title = 'Users';
    
    // View data for
    protected static $userGroup = [
        'site_manager' => 'Site Manager',
        'cleaning' => 'Cleaner',
        'maintenance' => 'Maintenance',
        'data_manager' => 'Data Manager',
        'supervising' => 'Supervisor'
    ]; 

    public function index()
    {
        $sites=array();
        
        ///// if site manager ////
        if(Auth::user()->role==3)
        {
            $sites = SiteUser::where('user_id',Auth::user()->id)->where('active',1)->groupBy('user_id')->paginate(Config::get('constants.page_limit'));
        }else{
            $sites = SiteUser::where('active',1)->groupBy('user_id')->paginate(Config::get('constants.page_limit'));
        }

        $data=array();
        if(!empty($sites))
        {
            $i=0;
            foreach($sites as $key=>$s)
            {
                $data['site_users'][$i]['id']=$s['id'];
                $data['site_users'][$i]['site_id']=$s['site_id'];
                $data['site_users'][$i]['user_id']=$s['user_id'];
                $site = Site::where('id',$s['site_id'])->first();
                $data['site_users'][$i]['site_name']=$site->name;
                $user = User::where('id',$s['user_id'])->first();
                $data['site_users'][$i]['login_key']=$user->login_key;
                $data['site_users'][$i]['name']=$user->name;
                $data['site_users'][$i]['email']=$user->email;
                $data['site_users'][$i]['contact_no']=$user->contact_no;
                $data['site_users'][$i]['username']=$user->username;
                
                $i++;
            }
        }
        $links = $sites->links();
        return view('admin.site_users.index',['site_users'=>$data,'links'=>$links,'title'=>static::$title]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $sites=array();
        $sites = Site::where('active',1)->select('name', 'id')->get()->toArray();
        return view('admin.site_users.create',['sites'=>$sites,'title'=>static::$title,'user_group'=>static::$userGroup]);
    }

    public function store(SiteUsersRequest $request)
    {
        $last_user_id = User::select('id')->orderBy('id', 'desc')->first()->id;
        $login_key = '1100'.$last_user_id;
        if($request->user_group == 'site_manager'){
            $role=3;
        }else if($request->user_group == 'cleaning'){
            $role=4;
        }else if($request->user_group == 'maintenance'){
            $role=5;
        }else if($request->user_group == 'data_manager'){
            $role=6;
        }else if($request->user_group == 'supervising'){
            $role=7;
        }
        //// add user ///////
        $user = User::create([
            'role' => $role,
            'user_group'=>$request->user_group,
            'username' => $request->username,
            'name' => $request->name,
            'email' => $request->email,
            'contact_no' => $request->contact_no,
            'password' => Hash::make($request->password),
            'login_key'=>$login_key,
            'company_id'=>Auth::user()->id,
            'db_name'=>Auth::user()->db_name
        ]);
        if($user)
        {
            $site_user_data=array();
            //// add site user /////
            foreach($request->site_id as $su)
            {
                $site_user_data[] = [
                    'site_id' => $su,
                    'user_id' => $user->id,
                    'created_at' => date('Y-m-d H:i:s'),
                    'created_by' => Auth::user()->id
                ];
            }
            SiteUser::insert($site_user_data);
            
            return redirect()->route('site_users.index')->with('message', 'User added successfully.');
        }

        return redirect()->back()
        ->withInput();
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Company  $company
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Company  $company
     * @return \Illuminate\Http\Response
    */
    public function edit($user_id)
    {
        if($user_id)
        {
            $sites=array();
            $sites = Site::where('active',1)->select('name', 'id')->get()->toArray();

            $selected_site_id = SiteUser::select('site_id')->where('user_id',$user_id)->where('active',1)->get()->toArray();
            $selected_site_ids=array();
            foreach($selected_site_id as $s)
            {
                $selected_site_ids[]=$s['site_id'];
            }
            $site_user = User::find($user_id);            
            if($site_user)
            {
                return view('admin.site_users.edit', ['selected_site_ids'=>$selected_site_ids,'sites'=>$sites,'site_user' => $site_user,'title'=>static::$title,'is_edit'=>1,'user_group'=>static::$userGroup]);
            }
        }

        abort(404);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Company  $company
     * @return \Illuminate\Http\Response
     */
    public function update(SiteUsersRequest $request, $id)
    {
        if($id)
        {
            $post = $request->all();
            $post['updated_by']=Auth::user()->id;
            $company = User::find($id);

            if($post && $company)
            {
                if($company->update($post))
                {
                    $selected_site_id = SiteUser::select('site_id')->where('user_id',$id)->where('active',1)->get()->toArray();
                    $selected_site_ids=array();
                    foreach($selected_site_id as $s)
                    {
                        $selected_site_ids[]=$s['site_id'];
                    }

                    $remove_site_ids = array_diff($selected_site_ids,$request->site_id);
                    $remove_site_ids = array_values($remove_site_ids);

                    $deactivate_data['active']=0;
                    $res=SiteUser::whereIn('site_id',$remove_site_ids)->update($deactivate_data);

                    foreach($request->site_id as $su)
                    {
                        $site_User = SiteUser::updateOrCreate([
                            'site_id' => $su,
                            'user_id' => $id
                        ],[
                            'site_id' => $su,
                            'user_id' => $id,
                            'active' => 1,
                            'updated_at' => date('Y-m-d H:i:s'),
                            'updated_by' => Auth::user()->id
                        ]);
                    }
                    return redirect()->route('site_users.index')->with('message', 'User edited successfully.');
                }
            }

            return redirect()->back()->with('error', __('messages.somethingWrong'));
        }

        abort(404);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Company  $company
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $up_data['deleted_by'] = Auth::user()->id;
        User::find($id)->update($up_data);
        
        User::find($id)->delete();
  
        return redirect()->back()->with('message', 'Company deleted successfully.');
    }

    public function restoreAll()
    {
        User::onlyTrashed()->restore();
  
        return redirect()->back();
    }
}
