<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Facades\Config;
use Illuminate\Support\Facades\DB;

class Ratings extends Model
{
    use HasFactory;
    use SoftDeletes;

    public $connection = 'mysql2';

   
    /**
     * The table associated with the model.
     *
     * @var string
    */ 
    protected $table = 'ratings';

    /**
     * set primary key of table
     *
     * @var integer
     */
    //protected $primaryKey = 'id';

    /**
     * Indicates if the model should be timestamped.
     *
     * @var bool
     */
    public $timestamps = true;

    

    /**
     * fillable column name goes here
     *
     * @var array
     */
    protected $fillable = [
        'id',
        'company_id',
        'site_id',
        'monitor_id',
        'servey_id',
        'servey_response',
        'positive',
        'negative',
        'nuetral',
        'positive_avg',
        'negative_avg',
        'neutral_avg',
        'positive_per',
        'negative_per',
        'neutral_per',
        'question_count',
        'performance',
        'date',
        'time',
        'datetime',
        'created_by',
        'updated_by',
        'deleted_by'
    ];

    public function servey()
    {
        return $this->hasOne('\App\Models\Servey','id','servey_id')->select(['id','name']);
    }

    public function customer_details()
    {
        return $this->hasOne('\App\Models\RatingCustomerDetails','rating_id','id');
    }

    function list($monitor_id=0,$from_date='',$to_date='')
    {
        $ratings = Ratings::query();
        $ratings->with('servey')->select('id','site_id','monitor_id','servey_id','positive','negative','nuetral','created_at');
        if (!empty($monitor_id)) {
            $ratings->where('monitor_id',$monitor_id);
        }
        if (!empty($from_date)) {
            $ratings->whereDate('created_at','>=',$from_date);
        }
        if (!empty($to_date)) {
            $ratings->whereDate('created_at','<=',$to_date);
        }
        $ratings->orderBy('created_at','desc');
        return $ratings->paginate(Config::get('constants.page_limit'));
    }

    function rating_calc($monitor_id=0,$from_date='',$to_date='')
    {
       // echo $monitor_id.','.$from_date.','.$to_date;
       $ratings = DB::connection('mysql2')->table('ratings')->select(DB::raw('SUM(positive) as total_positive') , DB::raw('(AVG(positive_avg)) as positive_avg'), 
        DB::raw('AVG(positive_per) as positive_per'),
        DB::raw('SUM(negative) as total_negative') , DB::raw('(AVG(negative_avg)) as negative_avg'),
        DB::raw('AVG(negative_per) as negative_per'),
        DB::raw('SUM(nuetral) as total_neutral') , DB::raw('(AVG(neutral_avg)) as neutral_avg'),
        DB::raw('AVG(neutral_per) as neutral_per')
        )
        ->where(function($query) use ($monitor_id,$from_date,$to_date) {
            if(!empty($monitor_id)){
                $query->where('monitor_id',$monitor_id);
            }
            if (!empty($from_date)) {
                $query->whereDate('date','>=',$from_date);
            }
            if (!empty($to_date)) {
                $query->whereDate('date','<=',$to_date);
            }
        })
        ->first();
        $sum=$positive_tone_count=$negative_tone_count=$neutral_tone_count=0;
        if(!empty($ratings))
        {
            $data['positive_count'] = $positive_tone_count= $ratings->total_positive;
            $data['neutral_count'] = $neutral_tone_count = $ratings->total_neutral;
            $data['negative_count'] = $negative_tone_count = $ratings->total_negative;

            $sum = $data['positive_count'] + $data['neutral_count'] + $data['negative_count'];
            $data['total_sum'] = $sum;
            $question_count = $sum;
    
            $data['positive_tone_performance'] = $positive_tone_performance =  ($question_count!=0) ? $positive_tone_count/$question_count : 0;
            $data['negative_tone_performance'] = $negative_tone_performance =  ($question_count!=0) ? $negative_tone_count/$question_count : 0;
            $data['neutral_tone_performance'] = $neutral_tone_performance =  ($question_count!=0) ? $neutral_tone_count/$question_count : 0;
            
            $data['positive_per']=$ratings->positive_per;
            $data['negative_per']=$ratings->negative_per;
            $data['neutral_per']=$ratings->neutral_per;
    
    
            $data['performance'] = $final_performance = max($positive_tone_performance,$negative_tone_performance,$neutral_tone_performance);
        
        }
        return $data;
        //echo '<pre>';print_r($data);echo '</pre>';exit;
    }

    function rating_in_per_houlrly_chart_data($monitor_id=0,$from_date='',$to_date='')
    {
        return $ratings = DB::connection('mysql2')->table('hourly_ratings')->select(
        DB::raw('IFNULL(SUM(0_hr),0) as r0'),DB::raw('IFNULL(SUM(1_hr),0) as r1'),DB::raw('IFNULL(SUM(2_hr),0) as r2'),DB::raw('IFNULL(IFNULL(SUM(3_hr),0),0) as r3'),DB::raw('IFNULL(SUM(4_hr),0) as r4'),DB::raw('IFNULL(IFNULL(SUM(5_hr),0),0) as r5'),DB::raw('IFNULL(SUM(6_hr),0) as r6'),
        DB::raw('IFNULL(SUM(7_hr),0) as r7'),DB::raw('IFNULL(SUM(8_hr),0) as r8'),DB::raw('IFNULL(SUM(9_hr),0) as r9'),DB::raw('IFNULL(SUM(10_hr),0) as r10'),DB::raw('IFNULL(SUM(11_hr),0) as r11'),DB::raw('IFNULL(SUM(12_hr),0) as r12'),DB::raw('IFNULL(SUM(13_hr),0) as r13'),
        DB::raw('IFNULL(SUM(14_hr),0) as r14'),DB::raw('IFNULL(SUM(15_hr),0) as r15'),DB::raw('IFNULL(SUM(16_hr),0) as r16'),DB::raw('IFNULL(SUM(17_hr),0) as r17'),DB::raw('IFNULL(SUM(18_hr),0) as r18'),DB::raw('IFNULL(SUM(19_hr),0) as r19'),DB::raw('IFNULL(SUM(20_hr),0) as r20'),
        DB::raw('IFNULL(SUM(21_hr),0) as r21'),DB::raw('IFNULL(SUM(22_hr),0) as r22'),DB::raw('IFNULL(SUM(23_hr),0) as r23')
        )
        ->groupBy('rating')
        ->where(function($query) use ($monitor_id,$from_date,$to_date) {
            if(!empty($monitor_id)){
                $query->where('monitor_id',$monitor_id);
            }
            if (!empty($from_date)) {
                $query->whereDate('date','>=',$from_date);
            }
            if (!empty($to_date)) {
                $query->whereDate('date','<=',$to_date);
            }
        })
        ->get()->toArray();
        
    }

    ////// Weekly heat map data ////
    function old__monthly_rating_in_per_houlrly_chart_data($monitor_id=0,$table='hourly_ratings',$params,$m_dates='',$t_dates='',$wed_dates='',$thur_dates='')
    {
        $monday=[];
        
        $m_dates = !empty($params['mondays']) ? $params['mondays'] : array('1970-12-12');
        $monday = DB::connection('mysql2')->table('hourly_ratings')->select(
            DB::raw('IFNULL(SUM(0_hr),0) as r0'),DB::raw('IFNULL(SUM(1_hr),0) as r1'),DB::raw('IFNULL(SUM(2_hr),0) as r2'),DB::raw('IFNULL(IFNULL(SUM(3_hr),0),0) as r3'),DB::raw('IFNULL(SUM(4_hr),0) as r4'),DB::raw('IFNULL(IFNULL(SUM(5_hr),0),0) as r5'),DB::raw('IFNULL(SUM(6_hr),0) as r6'),
            DB::raw('IFNULL(SUM(7_hr),0) as r7'),DB::raw('IFNULL(SUM(8_hr),0) as r8'),DB::raw('IFNULL(SUM(9_hr),0) as r9'),DB::raw('IFNULL(SUM(10_hr),0) as r10'),DB::raw('IFNULL(SUM(11_hr),0) as r11'),DB::raw('IFNULL(SUM(12_hr),0) as r12'),DB::raw('IFNULL(SUM(13_hr),0) as r13'),
            DB::raw('IFNULL(SUM(14_hr),0) as r14'),DB::raw('IFNULL(SUM(15_hr),0) as r15'),DB::raw('IFNULL(SUM(16_hr),0) as r16'),DB::raw('IFNULL(SUM(17_hr),0) as r17'),DB::raw('IFNULL(SUM(18_hr),0) as r18'),DB::raw('IFNULL(SUM(19_hr),0) as r19'),DB::raw('IFNULL(SUM(20_hr),0) as r20'),
            DB::raw('IFNULL(SUM(21_hr),0) as r21'),DB::raw('IFNULL(SUM(22_hr),0) as r22'),DB::raw('IFNULL(SUM(23_hr),0) as r23')
            )
            ->where('rating',3)
            ->where(function($query) use ($monitor_id,$m_dates) {
                if(!empty($monitor_id)){
                    $query->where('monitor_id',$monitor_id);
                }
                if (!empty($m_dates)) {
                    $query->whereIn('date',$m_dates);
                }
        })->get()->toArray();
        
       
        $tuesday=[];
        
        $t_dates = !empty($params['tuesdays']) ? $params['tuesdays'] : array('1970-12-12');
        $tuesday = DB::connection('mysql2')->table('hourly_ratings')->select(
            DB::raw('IFNULL(SUM(0_hr),0) as r0'),DB::raw('IFNULL(SUM(1_hr),0) as r1'),DB::raw('IFNULL(SUM(2_hr),0) as r2'),DB::raw('IFNULL(IFNULL(SUM(3_hr),0),0) as r3'),DB::raw('IFNULL(SUM(4_hr),0) as r4'),DB::raw('IFNULL(IFNULL(SUM(5_hr),0),0) as r5'),DB::raw('IFNULL(SUM(6_hr),0) as r6'),
            DB::raw('IFNULL(SUM(7_hr),0) as r7'),DB::raw('IFNULL(SUM(8_hr),0) as r8'),DB::raw('IFNULL(SUM(9_hr),0) as r9'),DB::raw('IFNULL(SUM(10_hr),0) as r10'),DB::raw('IFNULL(SUM(11_hr),0) as r11'),DB::raw('IFNULL(SUM(12_hr),0) as r12'),DB::raw('IFNULL(SUM(13_hr),0) as r13'),
            DB::raw('IFNULL(SUM(14_hr),0) as r14'),DB::raw('IFNULL(SUM(15_hr),0) as r15'),DB::raw('IFNULL(SUM(16_hr),0) as r16'),DB::raw('IFNULL(SUM(17_hr),0) as r17'),DB::raw('IFNULL(SUM(18_hr),0) as r18'),DB::raw('IFNULL(SUM(19_hr),0) as r19'),DB::raw('IFNULL(SUM(20_hr),0) as r20'),
            DB::raw('IFNULL(SUM(21_hr),0) as r21'),DB::raw('IFNULL(SUM(22_hr),0) as r22'),DB::raw('IFNULL(SUM(23_hr),0) as r23')
            )
            ->where('rating',3)
            ->where(function($query) use ($monitor_id,$t_dates) {
                if(!empty($monitor_id)){
                    $query->where('monitor_id',$monitor_id);
                }
                if (!empty($t_dates)) {
                    $query->whereIn('date',$t_dates);
                }
        })->get()->toArray();
        

        $wedday=[];
        
        $wed_dates = (!empty($params['wednesdays'])) ? $params['wednesdays'] : array('1970-12-12');
        $wedday = DB::connection('mysql2')->table('hourly_ratings')->select(
            DB::raw('IFNULL(SUM(0_hr),0) as r0'),DB::raw('IFNULL(SUM(1_hr),0) as r1'),DB::raw('IFNULL(SUM(2_hr),0) as r2'),DB::raw('IFNULL(IFNULL(SUM(3_hr),0),0) as r3'),DB::raw('IFNULL(SUM(4_hr),0) as r4'),DB::raw('IFNULL(IFNULL(SUM(5_hr),0),0) as r5'),DB::raw('IFNULL(SUM(6_hr),0) as r6'),
            DB::raw('IFNULL(SUM(7_hr),0) as r7'),DB::raw('IFNULL(SUM(8_hr),0) as r8'),DB::raw('IFNULL(SUM(9_hr),0) as r9'),DB::raw('IFNULL(SUM(10_hr),0) as r10'),DB::raw('IFNULL(SUM(11_hr),0) as r11'),DB::raw('IFNULL(SUM(12_hr),0) as r12'),DB::raw('IFNULL(SUM(13_hr),0) as r13'),
            DB::raw('IFNULL(SUM(14_hr),0) as r14'),DB::raw('IFNULL(SUM(15_hr),0) as r15'),DB::raw('IFNULL(SUM(16_hr),0) as r16'),DB::raw('IFNULL(SUM(17_hr),0) as r17'),DB::raw('IFNULL(SUM(18_hr),0) as r18'),DB::raw('IFNULL(SUM(19_hr),0) as r19'),DB::raw('IFNULL(SUM(20_hr),0) as r20'),
            DB::raw('IFNULL(SUM(21_hr),0) as r21'),DB::raw('IFNULL(SUM(22_hr),0) as r22'),DB::raw('IFNULL(SUM(23_hr),0) as r23')
            )
            ->where('rating',3)
            ->where(function($query) use ($monitor_id,$wed_dates) {
                if(!empty($monitor_id)){
                    $query->where('monitor_id',$monitor_id);
                }
                if (!empty($wed_dates)) {
                    $query->whereIn('date',$wed_dates);
                }
        })->get()->toArray();
      

        $thursday= [];
        
        $thur_dates = (!empty($params['thursday'])) ? $params['thursday'] : array('1970-12-12');
        $thursday = DB::connection('mysql2')->table('hourly_ratings')->select(
            DB::raw('IFNULL(SUM(0_hr),0) as r0'),DB::raw('IFNULL(SUM(1_hr),0) as r1'),DB::raw('IFNULL(SUM(2_hr),0) as r2'),DB::raw('IFNULL(IFNULL(SUM(3_hr),0),0) as r3'),DB::raw('IFNULL(SUM(4_hr),0) as r4'),DB::raw('IFNULL(IFNULL(SUM(5_hr),0),0) as r5'),DB::raw('IFNULL(SUM(6_hr),0) as r6'),
            DB::raw('IFNULL(SUM(7_hr),0) as r7'),DB::raw('IFNULL(SUM(8_hr),0) as r8'),DB::raw('IFNULL(SUM(9_hr),0) as r9'),DB::raw('IFNULL(SUM(10_hr),0) as r10'),DB::raw('IFNULL(SUM(11_hr),0) as r11'),DB::raw('IFNULL(SUM(12_hr),0) as r12'),DB::raw('IFNULL(SUM(13_hr),0) as r13'),
            DB::raw('IFNULL(SUM(14_hr),0) as r14'),DB::raw('IFNULL(SUM(15_hr),0) as r15'),DB::raw('IFNULL(SUM(16_hr),0) as r16'),DB::raw('IFNULL(SUM(17_hr),0) as r17'),DB::raw('IFNULL(SUM(18_hr),0) as r18'),DB::raw('IFNULL(SUM(19_hr),0) as r19'),DB::raw('IFNULL(SUM(20_hr),0) as r20'),
            DB::raw('IFNULL(SUM(21_hr),0) as r21'),DB::raw('IFNULL(SUM(22_hr),0) as r22'),DB::raw('IFNULL(SUM(23_hr),0) as r23')
            )
            ->where('rating',3)
            ->where(function($query) use ($monitor_id,$thur_dates) {
                if(!empty($monitor_id)){
                    $query->where('monitor_id',$monitor_id);
                }
                if (!empty($thur_dates)) {
                    $query->whereIn('date',$thur_dates);
                }
        })->get()->toArray();
        

        $fridays=[];
       
        $fr_dates = (!empty($params['fridays'])) ? $params['fridays'] : array('1970-12-12');
        $fridays = DB::connection('mysql2')->table('hourly_ratings')->select(
            DB::raw('IFNULL(SUM(0_hr),0) as r0'),DB::raw('IFNULL(SUM(1_hr),0) as r1'),DB::raw('IFNULL(SUM(2_hr),0) as r2'),DB::raw('IFNULL(IFNULL(SUM(3_hr),0),0) as r3'),DB::raw('IFNULL(SUM(4_hr),0) as r4'),DB::raw('IFNULL(IFNULL(SUM(5_hr),0),0) as r5'),DB::raw('IFNULL(SUM(6_hr),0) as r6'),
            DB::raw('IFNULL(SUM(7_hr),0) as r7'),DB::raw('IFNULL(SUM(8_hr),0) as r8'),DB::raw('IFNULL(SUM(9_hr),0) as r9'),DB::raw('IFNULL(SUM(10_hr),0) as r10'),DB::raw('IFNULL(SUM(11_hr),0) as r11'),DB::raw('IFNULL(SUM(12_hr),0) as r12'),DB::raw('IFNULL(SUM(13_hr),0) as r13'),
            DB::raw('IFNULL(SUM(14_hr),0) as r14'),DB::raw('IFNULL(SUM(15_hr),0) as r15'),DB::raw('IFNULL(SUM(16_hr),0) as r16'),DB::raw('IFNULL(SUM(17_hr),0) as r17'),DB::raw('IFNULL(SUM(18_hr),0) as r18'),DB::raw('IFNULL(SUM(19_hr),0) as r19'),DB::raw('IFNULL(SUM(20_hr),0) as r20'),
            DB::raw('IFNULL(SUM(21_hr),0) as r21'),DB::raw('IFNULL(SUM(22_hr),0) as r22'),DB::raw('IFNULL(SUM(23_hr),0) as r23')
            )
            ->where('rating',3)
            ->where(function($query) use ($monitor_id,$fr_dates) {
                if(!empty($monitor_id)){
                    $query->where('monitor_id',$monitor_id);
                }
                if (!empty($fr_dates)) {
                    $query->whereIn('date',$fr_dates);
                }
        })->get()->toArray();
      
        

        $saturdays=[];
       
        $sat_dates = (!empty($params['saturdays'])) ? $params['saturdays'] : array('1970-12-12');
        $saturdays = DB::connection('mysql2')->table('hourly_ratings')->select(
            DB::raw('IFNULL(SUM(0_hr),0) as r0'),DB::raw('IFNULL(SUM(1_hr),0) as r1'),DB::raw('IFNULL(SUM(2_hr),0) as r2'),DB::raw('IFNULL(IFNULL(SUM(3_hr),0),0) as r3'),DB::raw('IFNULL(SUM(4_hr),0) as r4'),DB::raw('IFNULL(IFNULL(SUM(5_hr),0),0) as r5'),DB::raw('IFNULL(SUM(6_hr),0) as r6'),
            DB::raw('IFNULL(SUM(7_hr),0) as r7'),DB::raw('IFNULL(SUM(8_hr),0) as r8'),DB::raw('IFNULL(SUM(9_hr),0) as r9'),DB::raw('IFNULL(SUM(10_hr),0) as r10'),DB::raw('IFNULL(SUM(11_hr),0) as r11'),DB::raw('IFNULL(SUM(12_hr),0) as r12'),DB::raw('IFNULL(SUM(13_hr),0) as r13'),
            DB::raw('IFNULL(SUM(14_hr),0) as r14'),DB::raw('IFNULL(SUM(15_hr),0) as r15'),DB::raw('IFNULL(SUM(16_hr),0) as r16'),DB::raw('IFNULL(SUM(17_hr),0) as r17'),DB::raw('IFNULL(SUM(18_hr),0) as r18'),DB::raw('IFNULL(SUM(19_hr),0) as r19'),DB::raw('IFNULL(SUM(20_hr),0) as r20'),
            DB::raw('IFNULL(SUM(21_hr),0) as r21'),DB::raw('IFNULL(SUM(22_hr),0) as r22'),DB::raw('IFNULL(SUM(23_hr),0) as r23')
            )
            ->where('rating',3)
            ->where(function($query) use ($monitor_id,$sat_dates) {
                if(!empty($monitor_id)){
                    $query->where('monitor_id',$monitor_id);
                }
                if (!empty($sat_dates)) {
                    $query->whereIn('date',$sat_dates);
                }
        })->get()->toArray();
    
        
        $sundays=[];
       
        $sun_dates = (!empty($params['sundays'])) ? $params['sundays'] : array('1970-12-12');
        $sundays = DB::connection('mysql2')->table('hourly_ratings')->select(
            DB::raw('IFNULL(SUM(0_hr),0) as r0'),DB::raw('IFNULL(SUM(1_hr),0) as r1'),DB::raw('IFNULL(SUM(2_hr),0) as r2'),DB::raw('IFNULL(IFNULL(SUM(3_hr),0),0) as r3'),DB::raw('IFNULL(SUM(4_hr),0) as r4'),DB::raw('IFNULL(IFNULL(SUM(5_hr),0),0) as r5'),DB::raw('IFNULL(SUM(6_hr),0) as r6'),
            DB::raw('IFNULL(SUM(7_hr),0) as r7'),DB::raw('IFNULL(SUM(8_hr),0) as r8'),DB::raw('IFNULL(SUM(9_hr),0) as r9'),DB::raw('IFNULL(SUM(10_hr),0) as r10'),DB::raw('IFNULL(SUM(11_hr),0) as r11'),DB::raw('IFNULL(SUM(12_hr),0) as r12'),DB::raw('IFNULL(SUM(13_hr),0) as r13'),
            DB::raw('IFNULL(SUM(14_hr),0) as r14'),DB::raw('IFNULL(SUM(15_hr),0) as r15'),DB::raw('IFNULL(SUM(16_hr),0) as r16'),DB::raw('IFNULL(SUM(17_hr),0) as r17'),DB::raw('IFNULL(SUM(18_hr),0) as r18'),DB::raw('IFNULL(SUM(19_hr),0) as r19'),DB::raw('IFNULL(SUM(20_hr),0) as r20'),
            DB::raw('IFNULL(SUM(21_hr),0) as r21'),DB::raw('IFNULL(SUM(22_hr),0) as r22'),DB::raw('IFNULL(SUM(23_hr),0) as r23')
            )
            ->where('rating',3)
            ->where(function($query) use ($monitor_id,$sun_dates) {
                if(!empty($monitor_id)){
                    $query->where('monitor_id',$monitor_id);
                }
                if (!empty($sun_dates)) {
                    $query->whereIn('date',$sun_dates);
                }
        })->get()->toArray();
   
        
        //$result = $monday->merge($tuesday)->merge($wedday)->merge($thursday)->merge($fridays)->merge($saturdays)->merge($sundays);
        $result = array_merge($monday,$tuesday,$wedday,$thursday,$fridays,$saturdays,$sundays);
        //echo '<pre>';print_r($result);echo '</pre>';
        $final_heat_data=[];
        if(!empty($result))
        {
            $final_mon_heat_data = $final_tue_heat_data = $final_wed_heat_data = $final_thurs_heat_data = $final_fri_heat_data = $final_sat_heat_data = $final_sun_heat_data = [];
            $heat_mon_data = $heat_tue_data = $heat_wed_data = $heat_thur_data = $heat_fri_data = $heat_sat_data = $heat_sun_data = [];
            for ($t = 0; $t <= 23; $t++) {

                $v1 = "r".$t;
                $heat_mon_data["x"] = $t;
                $heat_mon_data["y"] = "Monday";
                $heat_mon_data["heat"] = $result[0]->$v1;
                if($result[0]->$v1 == 0)
                {
                    $heat_mon_data["fill"] = "#ffffff";
                }

                //echo '<pre>';print_r($heat_mon_data);echo '</pre>';
                $v2 = "r".$t;
                $heat_tue_data["x"] = $t;
                $heat_tue_data["y"] = "Tuesday";
                $heat_tue_data["heat"] = $result[1]->$v2;
                if($result[1]->$v2 == 0)
                {
                    $heat_tue_data["fill"] = "#ffffff";
                }

                $v3 = "r".$t;
                $heat_wed_data["x"] = $t;
                $heat_wed_data["y"] = "Wednesday";
                $heat_wed_data["heat"] = $result[2]->$v3;
                if($result[2]->$v3 == 0)
                {
                    $heat_wed_data["fill"] = "#ffffff";
                }

                $v4 = "r".$t;
                $heat_thur_data["x"] = $t;
                $heat_thur_data["y"] = "Thursday";
                $heat_thur_data["heat"] = $result[3]->$v4;
                if($result[3]->$v4 == 0)
                {
                    $heat_thur_data["fill"] = "#ffffff";
                }

                $v5 = "r".$t;
                $heat_fri_data["x"] = $t;
                $heat_fri_data["y"] = "Friday";
                $heat_fri_data["heat"] = $result[4]->$v5;
                if($result[4]->$v5 == 0)
                {
                    $heat_fri_data["fill"] = "#ffffff";
                }

                $v6 = "r".$t;
                $heat_sat_data["x"] = $t;
                $heat_sat_data["y"] = "Saturday";
                $heat_sat_data["heat"] = $result[5]->$v6;
                if($result[5]->$v6 == 0)
                {
                    $heat_sat_data["fill"] = "#ffffff";
                }
                

                $v7 = "r".$t;
                $heat_sun_data["x"] = $t;
                $heat_sun_data["y"] = "Sunday";
                $heat_sun_data["heat"] = $result[6]->$v7;
                if($result[6]->$v7 == 0)
                {
                    $heat_sun_data["fill"] = "#ffffff";
                }

                $final_mon_heat_data[] = $heat_mon_data;
                $final_tue_heat_data[] = $heat_tue_data;
                $final_wed_heat_data[] = $heat_wed_data;
                $final_thurs_heat_data[] = $heat_thur_data;
                $final_fri_heat_data[] = $heat_fri_data;
                $final_sat_heat_data[] = $heat_sat_data;
                $final_sun_heat_data[] = $heat_sun_data;
            }
            $monday_data = $this->filter_day_array($final_mon_heat_data);
            $tuesday_data = $this->filter_day_array($final_tue_heat_data);            $wed_data = $this->filter_day_array($final_wed_heat_data);
            $thurs_data = $this->filter_day_array($final_thurs_heat_data);
            $fri_data = $this->filter_day_array($final_fri_heat_data);
            $sat_data = $this->filter_day_array($final_sat_heat_data);
            $sun_data = $this->filter_day_array($final_sun_heat_data);
            //print_r($found); 
           
            $final_heat_data = array_merge($monday_data,$tuesday_data,$wed_data,$thurs_data,$fri_data,$sat_data,$sun_data);
           
        }        
        
        return json_encode($final_heat_data);

        // ->where(function($query) use ($monitor_id,$t_dates) {
        //     if(!empty($monitor_id)){
        //         $query->where('monitor_id',$monitor_id);
        //     }
        //     if (!empty($dates)) {
        //         $query->whereIn('date',$t_dates);
        //     }
        // })
        //->get()->toArray();
    }

    function monthly_rating_in_per_houlrly_chart_data($monitor_id=0,$params,$question_id,$table='hourly_ratings')
    {
        $monday=[];
        
        $m_dates = !empty($params['mondays']) ? $params['mondays'] : array('1970-12-12');
        $monday = DB::connection('mysql2')->table($table)->select(
            DB::raw('IFNULL(SUM(0_hr),0) as r0'),DB::raw('IFNULL(SUM(1_hr),0) as r1'),DB::raw('IFNULL(SUM(2_hr),0) as r2'),DB::raw('IFNULL(IFNULL(SUM(3_hr),0),0) as r3'),DB::raw('IFNULL(SUM(4_hr),0) as r4'),DB::raw('IFNULL(IFNULL(SUM(5_hr),0),0) as r5'),DB::raw('IFNULL(SUM(6_hr),0) as r6'),
            DB::raw('IFNULL(SUM(7_hr),0) as r7'),DB::raw('IFNULL(SUM(8_hr),0) as r8'),DB::raw('IFNULL(SUM(9_hr),0) as r9'),DB::raw('IFNULL(SUM(10_hr),0) as r10'),DB::raw('IFNULL(SUM(11_hr),0) as r11'),DB::raw('IFNULL(SUM(12_hr),0) as r12'),DB::raw('IFNULL(SUM(13_hr),0) as r13'),
            DB::raw('IFNULL(SUM(14_hr),0) as r14'),DB::raw('IFNULL(SUM(15_hr),0) as r15'),DB::raw('IFNULL(SUM(16_hr),0) as r16'),DB::raw('IFNULL(SUM(17_hr),0) as r17'),DB::raw('IFNULL(SUM(18_hr),0) as r18'),DB::raw('IFNULL(SUM(19_hr),0) as r19'),DB::raw('IFNULL(SUM(20_hr),0) as r20'),
            DB::raw('IFNULL(SUM(21_hr),0) as r21'),DB::raw('IFNULL(SUM(22_hr),0) as r22'),DB::raw('IFNULL(SUM(23_hr),0) as r23')
            )
            ->where('rating',3)
            ->where(function($query) use ($monitor_id,$question_id,$m_dates) {
                if(!empty($monitor_id)){
                    $query->where('monitor_id',$monitor_id);
                }
                if(!empty($question_id)){
                    $query->where('question_id',$question_id);
                }
                if (!empty($m_dates)) {
                    $query->whereIn('date',$m_dates);
                }
        })->get()->toArray();
        
       
        $tuesday=[];
        
        $t_dates = !empty($params['tuesdays']) ? $params['tuesdays'] : array('1970-12-12');
        $tuesday = DB::connection('mysql2')->table($table)->select(
            DB::raw('IFNULL(SUM(0_hr),0) as r0'),DB::raw('IFNULL(SUM(1_hr),0) as r1'),DB::raw('IFNULL(SUM(2_hr),0) as r2'),DB::raw('IFNULL(IFNULL(SUM(3_hr),0),0) as r3'),DB::raw('IFNULL(SUM(4_hr),0) as r4'),DB::raw('IFNULL(IFNULL(SUM(5_hr),0),0) as r5'),DB::raw('IFNULL(SUM(6_hr),0) as r6'),
            DB::raw('IFNULL(SUM(7_hr),0) as r7'),DB::raw('IFNULL(SUM(8_hr),0) as r8'),DB::raw('IFNULL(SUM(9_hr),0) as r9'),DB::raw('IFNULL(SUM(10_hr),0) as r10'),DB::raw('IFNULL(SUM(11_hr),0) as r11'),DB::raw('IFNULL(SUM(12_hr),0) as r12'),DB::raw('IFNULL(SUM(13_hr),0) as r13'),
            DB::raw('IFNULL(SUM(14_hr),0) as r14'),DB::raw('IFNULL(SUM(15_hr),0) as r15'),DB::raw('IFNULL(SUM(16_hr),0) as r16'),DB::raw('IFNULL(SUM(17_hr),0) as r17'),DB::raw('IFNULL(SUM(18_hr),0) as r18'),DB::raw('IFNULL(SUM(19_hr),0) as r19'),DB::raw('IFNULL(SUM(20_hr),0) as r20'),
            DB::raw('IFNULL(SUM(21_hr),0) as r21'),DB::raw('IFNULL(SUM(22_hr),0) as r22'),DB::raw('IFNULL(SUM(23_hr),0) as r23')
            )
            ->where('rating',3)
            ->where(function($query) use ($monitor_id,$question_id,$t_dates) {
                if(!empty($monitor_id)){
                    $query->where('monitor_id',$monitor_id);
                }
                if(!empty($question_id)){
                    $query->where('question_id',$question_id);
                }
                if (!empty($t_dates)) {
                    $query->whereIn('date',$t_dates);
                }
        })->get()->toArray();
        

        $wedday=[];
        
        $wed_dates = (!empty($params['wednesdays'])) ? $params['wednesdays'] : array('1970-12-12');
        $wedday = DB::connection('mysql2')->table($table)->select(
            DB::raw('IFNULL(SUM(0_hr),0) as r0'),DB::raw('IFNULL(SUM(1_hr),0) as r1'),DB::raw('IFNULL(SUM(2_hr),0) as r2'),DB::raw('IFNULL(IFNULL(SUM(3_hr),0),0) as r3'),DB::raw('IFNULL(SUM(4_hr),0) as r4'),DB::raw('IFNULL(IFNULL(SUM(5_hr),0),0) as r5'),DB::raw('IFNULL(SUM(6_hr),0) as r6'),
            DB::raw('IFNULL(SUM(7_hr),0) as r7'),DB::raw('IFNULL(SUM(8_hr),0) as r8'),DB::raw('IFNULL(SUM(9_hr),0) as r9'),DB::raw('IFNULL(SUM(10_hr),0) as r10'),DB::raw('IFNULL(SUM(11_hr),0) as r11'),DB::raw('IFNULL(SUM(12_hr),0) as r12'),DB::raw('IFNULL(SUM(13_hr),0) as r13'),
            DB::raw('IFNULL(SUM(14_hr),0) as r14'),DB::raw('IFNULL(SUM(15_hr),0) as r15'),DB::raw('IFNULL(SUM(16_hr),0) as r16'),DB::raw('IFNULL(SUM(17_hr),0) as r17'),DB::raw('IFNULL(SUM(18_hr),0) as r18'),DB::raw('IFNULL(SUM(19_hr),0) as r19'),DB::raw('IFNULL(SUM(20_hr),0) as r20'),
            DB::raw('IFNULL(SUM(21_hr),0) as r21'),DB::raw('IFNULL(SUM(22_hr),0) as r22'),DB::raw('IFNULL(SUM(23_hr),0) as r23')
            )
            ->where('rating',3)
            ->where(function($query) use ($monitor_id,$question_id,$wed_dates) {
                if(!empty($monitor_id)){
                    $query->where('monitor_id',$monitor_id);
                }
                if(!empty($question_id)){
                    $query->where('question_id',$question_id);
                }
                if (!empty($wed_dates)) {
                    $query->whereIn('date',$wed_dates);
                }
        })->get()->toArray();
      

        $thursday= [];
        
        $thur_dates = (!empty($params['thursday'])) ? $params['thursday'] : array('1970-12-12');
        $thursday = DB::connection('mysql2')->table($table)->select(
            DB::raw('IFNULL(SUM(0_hr),0) as r0'),DB::raw('IFNULL(SUM(1_hr),0) as r1'),DB::raw('IFNULL(SUM(2_hr),0) as r2'),DB::raw('IFNULL(IFNULL(SUM(3_hr),0),0) as r3'),DB::raw('IFNULL(SUM(4_hr),0) as r4'),DB::raw('IFNULL(IFNULL(SUM(5_hr),0),0) as r5'),DB::raw('IFNULL(SUM(6_hr),0) as r6'),
            DB::raw('IFNULL(SUM(7_hr),0) as r7'),DB::raw('IFNULL(SUM(8_hr),0) as r8'),DB::raw('IFNULL(SUM(9_hr),0) as r9'),DB::raw('IFNULL(SUM(10_hr),0) as r10'),DB::raw('IFNULL(SUM(11_hr),0) as r11'),DB::raw('IFNULL(SUM(12_hr),0) as r12'),DB::raw('IFNULL(SUM(13_hr),0) as r13'),
            DB::raw('IFNULL(SUM(14_hr),0) as r14'),DB::raw('IFNULL(SUM(15_hr),0) as r15'),DB::raw('IFNULL(SUM(16_hr),0) as r16'),DB::raw('IFNULL(SUM(17_hr),0) as r17'),DB::raw('IFNULL(SUM(18_hr),0) as r18'),DB::raw('IFNULL(SUM(19_hr),0) as r19'),DB::raw('IFNULL(SUM(20_hr),0) as r20'),
            DB::raw('IFNULL(SUM(21_hr),0) as r21'),DB::raw('IFNULL(SUM(22_hr),0) as r22'),DB::raw('IFNULL(SUM(23_hr),0) as r23')
            )
            ->where('rating',3)
            ->where(function($query) use ($monitor_id,$question_id,$thur_dates) {
                if(!empty($monitor_id)){
                    $query->where('monitor_id',$monitor_id);
                }
                if(!empty($question_id)){
                    $query->where('question_id',$question_id);
                }
                if (!empty($thur_dates)) {
                    $query->whereIn('date',$thur_dates);
                }
        })->get()->toArray();
        

        $fridays=[];
       
        $fr_dates = (!empty($params['fridays'])) ? $params['fridays'] : array('1970-12-12');
        $fridays = DB::connection('mysql2')->table($table)->select(
            DB::raw('IFNULL(SUM(0_hr),0) as r0'),DB::raw('IFNULL(SUM(1_hr),0) as r1'),DB::raw('IFNULL(SUM(2_hr),0) as r2'),DB::raw('IFNULL(IFNULL(SUM(3_hr),0),0) as r3'),DB::raw('IFNULL(SUM(4_hr),0) as r4'),DB::raw('IFNULL(IFNULL(SUM(5_hr),0),0) as r5'),DB::raw('IFNULL(SUM(6_hr),0) as r6'),
            DB::raw('IFNULL(SUM(7_hr),0) as r7'),DB::raw('IFNULL(SUM(8_hr),0) as r8'),DB::raw('IFNULL(SUM(9_hr),0) as r9'),DB::raw('IFNULL(SUM(10_hr),0) as r10'),DB::raw('IFNULL(SUM(11_hr),0) as r11'),DB::raw('IFNULL(SUM(12_hr),0) as r12'),DB::raw('IFNULL(SUM(13_hr),0) as r13'),
            DB::raw('IFNULL(SUM(14_hr),0) as r14'),DB::raw('IFNULL(SUM(15_hr),0) as r15'),DB::raw('IFNULL(SUM(16_hr),0) as r16'),DB::raw('IFNULL(SUM(17_hr),0) as r17'),DB::raw('IFNULL(SUM(18_hr),0) as r18'),DB::raw('IFNULL(SUM(19_hr),0) as r19'),DB::raw('IFNULL(SUM(20_hr),0) as r20'),
            DB::raw('IFNULL(SUM(21_hr),0) as r21'),DB::raw('IFNULL(SUM(22_hr),0) as r22'),DB::raw('IFNULL(SUM(23_hr),0) as r23')
            )
            ->where('rating',3)
            ->where(function($query) use ($monitor_id,$question_id,$fr_dates) {
                if(!empty($monitor_id)){
                    $query->where('monitor_id',$monitor_id);
                }
                if(!empty($question_id)){
                    $query->where('question_id',$question_id);
                }
                if (!empty($fr_dates)) {
                    $query->whereIn('date',$fr_dates);
                }
        })->get()->toArray();
      
        

        $saturdays=[];
       
        $sat_dates = (!empty($params['saturdays'])) ? $params['saturdays'] : array('1970-12-12');
        $saturdays = DB::connection('mysql2')->table($table)->select(
            DB::raw('IFNULL(SUM(0_hr),0) as r0'),DB::raw('IFNULL(SUM(1_hr),0) as r1'),DB::raw('IFNULL(SUM(2_hr),0) as r2'),DB::raw('IFNULL(IFNULL(SUM(3_hr),0),0) as r3'),DB::raw('IFNULL(SUM(4_hr),0) as r4'),DB::raw('IFNULL(IFNULL(SUM(5_hr),0),0) as r5'),DB::raw('IFNULL(SUM(6_hr),0) as r6'),
            DB::raw('IFNULL(SUM(7_hr),0) as r7'),DB::raw('IFNULL(SUM(8_hr),0) as r8'),DB::raw('IFNULL(SUM(9_hr),0) as r9'),DB::raw('IFNULL(SUM(10_hr),0) as r10'),DB::raw('IFNULL(SUM(11_hr),0) as r11'),DB::raw('IFNULL(SUM(12_hr),0) as r12'),DB::raw('IFNULL(SUM(13_hr),0) as r13'),
            DB::raw('IFNULL(SUM(14_hr),0) as r14'),DB::raw('IFNULL(SUM(15_hr),0) as r15'),DB::raw('IFNULL(SUM(16_hr),0) as r16'),DB::raw('IFNULL(SUM(17_hr),0) as r17'),DB::raw('IFNULL(SUM(18_hr),0) as r18'),DB::raw('IFNULL(SUM(19_hr),0) as r19'),DB::raw('IFNULL(SUM(20_hr),0) as r20'),
            DB::raw('IFNULL(SUM(21_hr),0) as r21'),DB::raw('IFNULL(SUM(22_hr),0) as r22'),DB::raw('IFNULL(SUM(23_hr),0) as r23')
            )
            ->where('rating',3)
            ->where(function($query) use ($monitor_id,$question_id,$sat_dates) {
                if(!empty($monitor_id)){
                    $query->where('monitor_id',$monitor_id);
                }
                if(!empty($question_id)){
                    $query->where('question_id',$question_id);
                }
                if (!empty($sat_dates)) {
                    $query->whereIn('date',$sat_dates);
                }
        })->get()->toArray();
    
        
        $sundays=[];
       
        $sun_dates = (!empty($params['sundays'])) ? $params['sundays'] : array('1970-12-12');
        $sundays = DB::connection('mysql2')->table($table)->select(
            DB::raw('IFNULL(SUM(0_hr),0) as r0'),DB::raw('IFNULL(SUM(1_hr),0) as r1'),DB::raw('IFNULL(SUM(2_hr),0) as r2'),DB::raw('IFNULL(IFNULL(SUM(3_hr),0),0) as r3'),DB::raw('IFNULL(SUM(4_hr),0) as r4'),DB::raw('IFNULL(IFNULL(SUM(5_hr),0),0) as r5'),DB::raw('IFNULL(SUM(6_hr),0) as r6'),
            DB::raw('IFNULL(SUM(7_hr),0) as r7'),DB::raw('IFNULL(SUM(8_hr),0) as r8'),DB::raw('IFNULL(SUM(9_hr),0) as r9'),DB::raw('IFNULL(SUM(10_hr),0) as r10'),DB::raw('IFNULL(SUM(11_hr),0) as r11'),DB::raw('IFNULL(SUM(12_hr),0) as r12'),DB::raw('IFNULL(SUM(13_hr),0) as r13'),
            DB::raw('IFNULL(SUM(14_hr),0) as r14'),DB::raw('IFNULL(SUM(15_hr),0) as r15'),DB::raw('IFNULL(SUM(16_hr),0) as r16'),DB::raw('IFNULL(SUM(17_hr),0) as r17'),DB::raw('IFNULL(SUM(18_hr),0) as r18'),DB::raw('IFNULL(SUM(19_hr),0) as r19'),DB::raw('IFNULL(SUM(20_hr),0) as r20'),
            DB::raw('IFNULL(SUM(21_hr),0) as r21'),DB::raw('IFNULL(SUM(22_hr),0) as r22'),DB::raw('IFNULL(SUM(23_hr),0) as r23')
            )
            ->where('rating',3)
            ->where(function($query) use ($monitor_id,$question_id,$sun_dates) {
                if(!empty($monitor_id)){
                    $query->where('monitor_id',$monitor_id);
                }
                if(!empty($question_id)){
                    $query->where('question_id',$question_id);
                }
                if (!empty($sun_dates)) {
                    $query->whereIn('date',$sun_dates);
                }
        })->get()->toArray();
   
        
        //$result = $monday->merge($tuesday)->merge($wedday)->merge($thursday)->merge($fridays)->merge($saturdays)->merge($sundays);
        $result = array_merge($monday,$tuesday,$wedday,$thursday,$fridays,$saturdays,$sundays);
        //echo '<pre>';print_r($result);echo '</pre>';
        $final_heat_data=[];
        if(!empty($result))
        {
            $final_mon_heat_data = $final_tue_heat_data = $final_wed_heat_data = $final_thurs_heat_data = $final_fri_heat_data = $final_sat_heat_data = $final_sun_heat_data = [];
            $heat_mon_data = $heat_tue_data = $heat_wed_data = $heat_thur_data = $heat_fri_data = $heat_sat_data = $heat_sun_data = [];
            for ($t = 0; $t <= 23; $t++) {

                $v1 = "r".$t;
                $heat_mon_data["x"] = $t;
                $heat_mon_data["y"] = "Monday";
                $heat_mon_data["heat"] = $result[0]->$v1;
                if($result[0]->$v1 == 0)
                {
                    $heat_mon_data["fill"] = "#ffffff";
                }

                //echo '<pre>';print_r($heat_mon_data);echo '</pre>';
                $v2 = "r".$t;
                $heat_tue_data["x"] = $t;
                $heat_tue_data["y"] = "Tuesday";
                $heat_tue_data["heat"] = $result[1]->$v2;
                if($result[1]->$v2 == 0)
                {
                    $heat_tue_data["fill"] = "#ffffff";
                }

                $v3 = "r".$t;
                $heat_wed_data["x"] = $t;
                $heat_wed_data["y"] = "Wednesday";
                $heat_wed_data["heat"] = $result[2]->$v3;
                if($result[2]->$v3 == 0)
                {
                    $heat_wed_data["fill"] = "#ffffff";
                }

                $v4 = "r".$t;
                $heat_thur_data["x"] = $t;
                $heat_thur_data["y"] = "Thursday";
                $heat_thur_data["heat"] = $result[3]->$v4;
                if($result[3]->$v4 == 0)
                {
                    $heat_thur_data["fill"] = "#ffffff";
                }

                $v5 = "r".$t;
                $heat_fri_data["x"] = $t;
                $heat_fri_data["y"] = "Friday";
                $heat_fri_data["heat"] = $result[4]->$v5;
                if($result[4]->$v5 == 0)
                {
                    $heat_fri_data["fill"] = "#ffffff";
                }

                $v6 = "r".$t;
                $heat_sat_data["x"] = $t;
                $heat_sat_data["y"] = "Saturday";
                $heat_sat_data["heat"] = $result[5]->$v6;
                if($result[5]->$v6 == 0)
                {
                    $heat_sat_data["fill"] = "#ffffff";
                }
                

                $v7 = "r".$t;
                $heat_sun_data["x"] = $t;
                $heat_sun_data["y"] = "Sunday";
                $heat_sun_data["heat"] = $result[6]->$v7;
                if($result[6]->$v7 == 0)
                {
                    $heat_sun_data["fill"] = "#ffffff";
                }

                $final_mon_heat_data[] = $heat_mon_data;
                $final_tue_heat_data[] = $heat_tue_data;
                $final_wed_heat_data[] = $heat_wed_data;
                $final_thurs_heat_data[] = $heat_thur_data;
                $final_fri_heat_data[] = $heat_fri_data;
                $final_sat_heat_data[] = $heat_sat_data;
                $final_sun_heat_data[] = $heat_sun_data;
            }
            $monday_data = $this->filter_day_array($final_mon_heat_data);
            $tuesday_data = $this->filter_day_array($final_tue_heat_data);
            $wed_data = $this->filter_day_array($final_wed_heat_data);
            $thurs_data = $this->filter_day_array($final_thurs_heat_data);
            $fri_data = $this->filter_day_array($final_fri_heat_data);
            $sat_data = $this->filter_day_array($final_sat_heat_data);
            $sun_data = $this->filter_day_array($final_sun_heat_data);
            //print_r($found); 
           
            $final_heat_data = array_merge($monday_data,$tuesday_data,$wed_data,$thurs_data,$fri_data,$sat_data,$sun_data);
           
        }        
        
        return json_encode($final_heat_data);

        // ->where(function($query) use ($monitor_id,$t_dates) {
        //     if(!empty($monitor_id)){
        //         $query->where('monitor_id',$monitor_id);
        //     }
        //     if (!empty($dates)) {
        //         $query->whereIn('date',$t_dates);
        //     }
        // })
        //->get()->toArray();
    }

    function filter_day_array($array)
    {
        $da=$key=[];
        foreach($array as $k=>$a)
        {
            if($a['heat'] > 0)
            {
                unset($array[$k]['fill']);
            }
        }
        return $array;
    }

    //////// Question Report //////
    function question_report_rating_calc($question_id,$from_date='',$to_date='')
    {
        $ratings =  DB::connection('mysql2')->table('rating_question_details')
        ->select('response_tone',
            DB::raw('COUNT(case when response_tone = 1 then 0 END) as `positive`'),
            DB::raw('COUNT(case when response_tone = 2 then 0 END) as `neutral`'),
            DB::raw('COUNT(case when response_tone = 3 then 0 END) as `negative`')
        )
        ->where(function($query) use ($question_id,$from_date,$to_date) {
            //if(!empty($question_id)){
                $query->whereIn('question_id',$question_id);
            //}
            if (!empty($from_date)) {
                $query->whereDate('date','>=',$from_date);
            }
            if (!empty($to_date)) {
                $query->whereDate('date','<=',$to_date);
            }
        })
        ->groupBy('response_tone')
        ->get()->toArray();
        /*
        select `response_tone`, sum(case when response_tone = 1 then 0 END) as `positive`, sum(case when response_tone = 2 then 0 END) as `neutral`, sum(case when response_tone = 3 then 0 END) as `negative` from `rating_question_details` where (`question_id` in (1,2,3,4,5,6,7,8,9) and date(`created_at`) >= '2022-07-28' and date(`created_at`) <= '2022-07-28') group by `response_tone`
        */
        $data=[];
        if(!empty($ratings))
        {
            $positive_key = array_search('1', array_column($ratings, 'response_tone'));
            $neutral_key = array_search('2', array_column($ratings, 'response_tone'));
            $negative_key = array_search('3', array_column($ratings, 'response_tone'));
            //echo '<pre>';print_r($ratings[$neutral_key]);echo '</pre>';
            $sum=$positive_tone_count=$negative_tone_count=$neutral_tone_count=0;
            if(isset($positive_key))
            {
                $data['positive_count'] = $positive_tone_count =$ratings[$positive_key]->positive;
                $sum += $data['positive_count'];
            }
            if(isset($neutral_key))
            {
                $data['neutral_count'] = $neutral_tone_count = $ratings[$neutral_key]->neutral;
                $sum += $data['neutral_count'];
            }
            if(isset($negative_key))
            {
                $data['negative_count'] = $negative_tone_count = $ratings[$negative_key]->negative;
                $sum += $data['negative_count'];
            }
        
            $data['total_sum'] = $sum;
            $question_count = $sum;
    
            $data['positive_tone_performance'] = $positive_tone_performance =  ($question_count!=0) ? $positive_tone_count/$question_count : 0;
            $data['negative_tone_performance'] = $negative_tone_performance =  ($question_count!=0) ? $negative_tone_count/$question_count : 0;
            $data['neutral_tone_performance'] = $neutral_tone_performance =  ($question_count!=0) ? $neutral_tone_count/$question_count : 0;
            
            $data['positive_per']=($positive_tone_performance*100);
            $data['negative_per']=($negative_tone_performance*100);
            $data['neutral_per']=($neutral_tone_performance*100);
    
    
            $data['performance'] = $final_performance = max($positive_tone_performance,$negative_tone_performance,$neutral_tone_performance);
        }
        return $data;
       
    }

    /////// Question houlrly ratings /////
    function question_rating_in_per_houlrly_chart_data($question_id,$from_date='',$to_date='')
    {
        return $ratings = DB::connection('mysql2')->table('hourly_question_ratings')->select(
        DB::raw('IFNULL(SUM(0_hr),0) as r0'),DB::raw('IFNULL(SUM(1_hr),0) as r1'),DB::raw('IFNULL(SUM(2_hr),0) as r2'),DB::raw('IFNULL(IFNULL(SUM(3_hr),0),0) as r3'),DB::raw('IFNULL(SUM(4_hr),0) as r4'),DB::raw('IFNULL(IFNULL(SUM(5_hr),0),0) as r5'),DB::raw('IFNULL(SUM(6_hr),0) as r6'),
        DB::raw('IFNULL(SUM(7_hr),0) as r7'),DB::raw('IFNULL(SUM(8_hr),0) as r8'),DB::raw('IFNULL(SUM(9_hr),0) as r9'),DB::raw('IFNULL(SUM(10_hr),0) as r10'),DB::raw('IFNULL(SUM(11_hr),0) as r11'),DB::raw('IFNULL(SUM(12_hr),0) as r12'),DB::raw('IFNULL(SUM(13_hr),0) as r13'),
        DB::raw('IFNULL(SUM(14_hr),0) as r14'),DB::raw('IFNULL(SUM(15_hr),0) as r15'),DB::raw('IFNULL(SUM(16_hr),0) as r16'),DB::raw('IFNULL(SUM(17_hr),0) as r17'),DB::raw('IFNULL(SUM(18_hr),0) as r18'),DB::raw('IFNULL(SUM(19_hr),0) as r19'),DB::raw('IFNULL(SUM(20_hr),0) as r20'),
        DB::raw('IFNULL(SUM(21_hr),0) as r21'),DB::raw('IFNULL(SUM(22_hr),0) as r22'),DB::raw('IFNULL(SUM(23_hr),0) as r23')
        )
        ->groupBy('rating')
        ->where(function($query) use ($question_id,$from_date,$to_date) {
            $query->whereIn('question_id',$question_id);
            if (!empty($from_date)) {
                $query->whereDate('date','>=',$from_date);
            }
            if (!empty($to_date)) {
                $query->whereDate('date','<=',$to_date);
            }
        })
        ->get()->toArray();
    }

    function top_N_feedbacks($monitor_id,$params=[],$question_id,$limit)
    {
        return $top_N_rating_text = DB::connection('mysql2')->table('rating_question_feedback_details')->join('feedback_questions', 'rating_question_feedback_details.feedback_question_id', '=', 'feedback_questions.id')
        ->selectRaw('rating_question_feedback_details.feedback_question, count(*) as count')
        ->where('feedback_questions.question_type',2)
        ->where(function($query) use ($monitor_id,$params) {
            if(!empty($monitor_id)){
                $query->where('monitor_id',$monitor_id);
            }
            if(!empty($question_id)){
                $query->where('question_id',$question_id);
            }
            if (!empty($params['from_date'])) {
                $query->whereDate('date','>=',$params['from_date']);
            }
            if (!empty($params['to_date'])) {
                $query->whereDate('date','<=',$params['to_date']);
            }       
        })
        ->groupBy('feedback_question')
        ->orderBy('count', 'DESC')
        ->limit($limit)
        ->get()->toArray();
        
        //echo '<pre>';print_r($top_N_rating_text);echo '</pre>';
        //"SELECT rating_question_feedback_details.feedback_question,count(*) as count FROM rating_question_feedback_details INNER JOIN feedback_questions ON rating_question_feedback_details.feedback_question_id = feedback_questions.id WHERE feedback_questions.question_type=2 GROUP BY feedback_question ORDER BY count DESC LIMIT 3"
    }

    function top_P_feedbacks($monitor_id,$params=[],$question_id,$limit)
    {
        return $top_N_rating_text = DB::connection('mysql2')->table('rating_question_feedback_details')->join('feedback_questions', 'rating_question_feedback_details.feedback_question_id', '=', 'feedback_questions.id')
        ->selectRaw('rating_question_feedback_details.feedback_question, count(*) as count')
        ->where('feedback_questions.question_type',1)
        ->where(function($query) use ($monitor_id,$params) {
            if(!empty($monitor_id)){
                $query->where('monitor_id',$monitor_id);
            }
            if(!empty($question_id)){
                $query->where('question_id',$question_id);
            }
            if (!empty($params['from_date'])) {
                $query->whereDate('date','>=',$params['from_date']);
            }
            if (!empty($params['to_date'])) {
                $query->whereDate('date','<=',$params['to_date']);
            }       
        })
        ->groupBy('feedback_question')
        ->orderBy('count', 'DESC')
        ->limit($limit)
        ->get()->toArray();
        
        //echo '<pre>';print_r($top_N_rating_text);echo '</pre>';
        //"SELECT rating_question_feedback_details.feedback_question,count(*) as count FROM rating_question_feedback_details INNER JOIN feedback_questions ON rating_question_feedback_details.feedback_question_id = feedback_questions.id WHERE feedback_questions.question_type=2 GROUP BY feedback_question ORDER BY count DESC LIMIT 3"
    }

}
